@@ -1,5 +1,5 @@
 import cv2
-from paddleocr import PaddleOCR
+from PaddleOCR.paddleocr import PaddleOCR
 import numpy as np
 import unicodedata as ud
 
